A simple Django app providing for
a simple way of using and storing weights and measures.

.. image:: https://travis-ci.org/latestrevision/django-measurement.png?branch=master
   :target: https://travis-ci.org/latestrevision/django-measurement

- Documentation for django-measurement is available an
  `ReadTheDocs <http://django-measurement.readthedocs.org/>`_.
- Please post issues on
  `BitBucket <http://bitbucket.org/latestrevision/django-measurement/issues?status=new&status=open>`_.
- Test status available on
  `Travis-CI <https://travis-ci.org/latestrevision/django-measurement>`_.

